pub struct Iter<'a, K, V> {
split: Split3<'a, SplayTreeSpec<K, V>>,
front: Vec<NonNull<BstNode<SplayTreeData<K, V>>>>,
back: Vec<NonNull<BstNode<SplayTreeData<K, V>>>>,
remaining: usize,
}Fields
split: Split3<'a, SplayTreeSpec<K, V>>front: Vec<NonNull<BstNode<SplayTreeData<K, V>>>>back: Vec<NonNull<BstNode<SplayTreeData<K, V>>>>remaining: usizeImplementations
Sourceimpl<'a, K, V> Iter<'a, K, V>
impl<'a, K, V> Iter<'a, K, V>
Sourcefn new(split: Split3<'a, SplayTreeSpec<K, V>>) -> Self
fn new(split: Split3<'a, SplayTreeSpec<K, V>>) -> Self
Examples found in repository?
crates/competitive/src/data_structure/splay_tree.rs (line 322)
321 pub fn iter(&mut self) -> Iter<'_, K, V> {
322 Iter::new(Split3::seek_by_size(&mut self.root, ..))
323 }
324
325 pub fn range<Q, R>(&mut self, range: R) -> Iter<'_, K, V>
326 where
327 K: Borrow<Q>,
328 Q: Ord + ?Sized,
329 R: RangeBounds<Q>,
330 {
331 Iter::new(Split3::seek_by_key(&mut self.root, range))
332 }
333
334 pub fn range_at<R>(&mut self, range: R) -> Iter<'_, K, V>
335 where
336 R: RangeBounds<usize>,
337 {
338 Iter::new(Split3::seek_by_size(&mut self.root, range))
339 }Sourcefn push_left(
node: NonNull<BstNode<SplayTreeData<K, V>>>,
stack: &mut Vec<NonNull<BstNode<SplayTreeData<K, V>>>>,
)
fn push_left( node: NonNull<BstNode<SplayTreeData<K, V>>>, stack: &mut Vec<NonNull<BstNode<SplayTreeData<K, V>>>>, )
Examples found in repository?
crates/competitive/src/data_structure/splay_tree.rs (line 370)
358 fn new(split: Split3<'a, SplayTreeSpec<K, V>>) -> Self {
359 let remaining = split
360 .mid()
361 .map(|node| node.into_data().size)
362 .unwrap_or_default();
363 let mut iter = Self {
364 split,
365 front: vec![],
366 back: vec![],
367 remaining,
368 };
369 if let Some(root) = iter.split.mid() {
370 Self::push_left(root.node, &mut iter.front);
371 Self::push_right(root.node, &mut iter.back);
372 }
373 iter
374 }
375
376 fn push_left(
377 mut node: NonNull<SplayTreeNode<K, V>>,
378 stack: &mut Vec<NonNull<SplayTreeNode<K, V>>>,
379 ) {
380 loop {
381 stack.push(node);
382 let Some(left) = (unsafe { node.as_ref().child[0] }) else {
383 break;
384 };
385 node = left;
386 }
387 }
388
389 fn push_right(
390 mut node: NonNull<SplayTreeNode<K, V>>,
391 stack: &mut Vec<NonNull<SplayTreeNode<K, V>>>,
392 ) {
393 loop {
394 stack.push(node);
395 let Some(right) = (unsafe { node.as_ref().child[1] }) else {
396 break;
397 };
398 node = right;
399 }
400 }
401}
402
403impl<K, V> Iterator for Iter<'_, K, V>
404where
405 K: Clone,
406 V: Clone,
407{
408 type Item = (K, V);
409
410 fn next(&mut self) -> Option<Self::Item> {
411 if self.remaining == 0 {
412 return None;
413 }
414 let node = self.front.pop().unwrap();
415 if let Some(right) = unsafe { node.as_ref().child[1] } {
416 Self::push_left(right, &mut self.front);
417 }
418 self.remaining -= 1;
419 let data = unsafe { &node.as_ref().data };
420 Some((data.key.clone(), data.value.clone()))
421 }Sourcefn push_right(
node: NonNull<BstNode<SplayTreeData<K, V>>>,
stack: &mut Vec<NonNull<BstNode<SplayTreeData<K, V>>>>,
)
fn push_right( node: NonNull<BstNode<SplayTreeData<K, V>>>, stack: &mut Vec<NonNull<BstNode<SplayTreeData<K, V>>>>, )
Examples found in repository?
crates/competitive/src/data_structure/splay_tree.rs (line 371)
358 fn new(split: Split3<'a, SplayTreeSpec<K, V>>) -> Self {
359 let remaining = split
360 .mid()
361 .map(|node| node.into_data().size)
362 .unwrap_or_default();
363 let mut iter = Self {
364 split,
365 front: vec![],
366 back: vec![],
367 remaining,
368 };
369 if let Some(root) = iter.split.mid() {
370 Self::push_left(root.node, &mut iter.front);
371 Self::push_right(root.node, &mut iter.back);
372 }
373 iter
374 }
375
376 fn push_left(
377 mut node: NonNull<SplayTreeNode<K, V>>,
378 stack: &mut Vec<NonNull<SplayTreeNode<K, V>>>,
379 ) {
380 loop {
381 stack.push(node);
382 let Some(left) = (unsafe { node.as_ref().child[0] }) else {
383 break;
384 };
385 node = left;
386 }
387 }
388
389 fn push_right(
390 mut node: NonNull<SplayTreeNode<K, V>>,
391 stack: &mut Vec<NonNull<SplayTreeNode<K, V>>>,
392 ) {
393 loop {
394 stack.push(node);
395 let Some(right) = (unsafe { node.as_ref().child[1] }) else {
396 break;
397 };
398 node = right;
399 }
400 }
401}
402
403impl<K, V> Iterator for Iter<'_, K, V>
404where
405 K: Clone,
406 V: Clone,
407{
408 type Item = (K, V);
409
410 fn next(&mut self) -> Option<Self::Item> {
411 if self.remaining == 0 {
412 return None;
413 }
414 let node = self.front.pop().unwrap();
415 if let Some(right) = unsafe { node.as_ref().child[1] } {
416 Self::push_left(right, &mut self.front);
417 }
418 self.remaining -= 1;
419 let data = unsafe { &node.as_ref().data };
420 Some((data.key.clone(), data.value.clone()))
421 }
422
423 fn last(mut self) -> Option<Self::Item> {
424 self.next_back()
425 }
426
427 fn min(mut self) -> Option<Self::Item> {
428 self.next()
429 }
430
431 fn max(mut self) -> Option<Self::Item> {
432 self.next_back()
433 }
434
435 fn size_hint(&self) -> (usize, Option<usize>) {
436 (self.remaining, Some(self.remaining))
437 }
438}
439
440impl<K, V> DoubleEndedIterator for Iter<'_, K, V>
441where
442 K: Clone,
443 V: Clone,
444{
445 fn next_back(&mut self) -> Option<Self::Item> {
446 if self.remaining == 0 {
447 return None;
448 }
449 let node = self.back.pop().unwrap();
450 if let Some(left) = unsafe { node.as_ref().child[0] } {
451 Self::push_right(left, &mut self.back);
452 }
453 self.remaining -= 1;
454 let data = unsafe { &node.as_ref().data };
455 Some((data.key.clone(), data.value.clone()))
456 }Trait Implementations
Sourceimpl<K, V> DoubleEndedIterator for Iter<'_, K, V>
impl<K, V> DoubleEndedIterator for Iter<'_, K, V>
Sourcefn next_back(&mut self) -> Option<Self::Item>
fn next_back(&mut self) -> Option<Self::Item>
Removes and returns an element from the end of the iterator. Read more
Sourcefn next_chunk_back<const N: usize>(
&mut self,
) -> Result<[Self::Item; N], IntoIter<Self::Item, N>>where
Self: Sized,
fn next_chunk_back<const N: usize>(
&mut self,
) -> Result<[Self::Item; N], IntoIter<Self::Item, N>>where
Self: Sized,
🔬This is a nightly-only experimental API. (
iter_next_chunk)Advances from the back of the iterator and returns an array containing the next
N values in sequence. Read moreSourcefn advance_back_by(&mut self, n: usize) -> Result<(), NonZero<usize>>
fn advance_back_by(&mut self, n: usize) -> Result<(), NonZero<usize>>
🔬This is a nightly-only experimental API. (
iter_advance_by)Advances the iterator from the back by
n elements. Read more1.37.0 (const: unstable) · Sourcefn nth_back(&mut self, n: usize) -> Option<Self::Item>
fn nth_back(&mut self, n: usize) -> Option<Self::Item>
Returns the
nth element from the end of the iterator. Read more1.27.0 (const: unstable) · Sourcefn try_rfold<B, F, R>(&mut self, init: B, f: F) -> R
fn try_rfold<B, F, R>(&mut self, init: B, f: F) -> R
This is the reverse version of
Iterator::try_fold(): it takes
elements starting from the back of the iterator. Read moreSourceimpl<K, V> ExactSizeIterator for Iter<'_, K, V>
impl<K, V> ExactSizeIterator for Iter<'_, K, V>
impl<K, V> FusedIterator for Iter<'_, K, V>
Sourceimpl<K, V> Iterator for Iter<'_, K, V>
impl<K, V> Iterator for Iter<'_, K, V>
Sourcefn next(&mut self) -> Option<Self::Item>
fn next(&mut self) -> Option<Self::Item>
Advances the iterator and returns the next value. Read more
Sourcefn last(self) -> Option<Self::Item>
fn last(self) -> Option<Self::Item>
Consumes the iterator, returning the last element. Read more
Sourcefn size_hint(&self) -> (usize, Option<usize>)
fn size_hint(&self) -> (usize, Option<usize>)
Returns the bounds on the remaining length of the iterator. Read more
Sourcefn next_chunk<const N: usize>(
&mut self,
) -> Result<[Self::Item; N], IntoIter<Self::Item, N>>where
Self: Sized,
fn next_chunk<const N: usize>(
&mut self,
) -> Result<[Self::Item; N], IntoIter<Self::Item, N>>where
Self: Sized,
🔬This is a nightly-only experimental API. (
iter_next_chunk)Advances the iterator and returns an array containing the next
N values. Read more1.0.0 (const: unstable) · Sourcefn count(self) -> usizewhere
Self: Sized,
fn count(self) -> usizewhere
Self: Sized,
Consumes the iterator, counting the number of iterations and returning it. Read more
Sourcefn advance_by(&mut self, n: usize) -> Result<(), NonZero<usize>>
fn advance_by(&mut self, n: usize) -> Result<(), NonZero<usize>>
🔬This is a nightly-only experimental API. (
iter_advance_by)Advances the iterator by
n elements. Read more1.0.0 (const: unstable) · Sourcefn nth(&mut self, n: usize) -> Option<Self::Item>
fn nth(&mut self, n: usize) -> Option<Self::Item>
Returns the
nth element of the iterator. Read more1.28.0 (const: unstable) · Sourcefn step_by(self, step: usize) -> StepBy<Self> ⓘwhere
Self: Sized,
fn step_by(self, step: usize) -> StepBy<Self> ⓘwhere
Self: Sized,
Creates an iterator starting at the same point, but stepping by
the given amount at each iteration. Read more
1.0.0 (const: unstable) · Sourcefn chain<U>(self, other: U) -> Chain<Self, <U as IntoIterator>::IntoIter> ⓘ
fn chain<U>(self, other: U) -> Chain<Self, <U as IntoIterator>::IntoIter> ⓘ
Takes two iterators and creates a new iterator over both in sequence. Read more
1.0.0 (const: unstable) · Sourcefn zip<U>(self, other: U) -> Zip<Self, <U as IntoIterator>::IntoIter> ⓘwhere
Self: Sized,
U: IntoIterator,
fn zip<U>(self, other: U) -> Zip<Self, <U as IntoIterator>::IntoIter> ⓘwhere
Self: Sized,
U: IntoIterator,
‘Zips up’ two iterators into a single iterator of pairs. Read more
Sourcefn intersperse(self, separator: Self::Item) -> Intersperse<Self> ⓘ
fn intersperse(self, separator: Self::Item) -> Intersperse<Self> ⓘ
🔬This is a nightly-only experimental API. (
iter_intersperse)Creates a new iterator which places a copy of
separator between items
of the original iterator. Read moreSourcefn intersperse_with<G>(self, separator: G) -> IntersperseWith<Self, G> ⓘ
fn intersperse_with<G>(self, separator: G) -> IntersperseWith<Self, G> ⓘ
🔬This is a nightly-only experimental API. (
iter_intersperse)Creates a new iterator which places an item generated by
separator
between items of the original iterator. Read more1.0.0 (const: unstable) · Sourcefn map<B, F>(self, f: F) -> Map<Self, F> ⓘ
fn map<B, F>(self, f: F) -> Map<Self, F> ⓘ
Takes a closure and creates an iterator which calls that closure on each
element. Read more
1.21.0 (const: unstable) · Sourcefn for_each<F>(self, f: F)
fn for_each<F>(self, f: F)
Calls a closure on each element of an iterator. Read more
1.0.0 (const: unstable) · Sourcefn filter<P>(self, predicate: P) -> Filter<Self, P> ⓘ
fn filter<P>(self, predicate: P) -> Filter<Self, P> ⓘ
Creates an iterator which uses a closure to determine if an element
should be yielded. Read more
1.0.0 (const: unstable) · Sourcefn filter_map<B, F>(self, f: F) -> FilterMap<Self, F> ⓘ
fn filter_map<B, F>(self, f: F) -> FilterMap<Self, F> ⓘ
Creates an iterator that both filters and maps. Read more
1.0.0 (const: unstable) · Sourcefn enumerate(self) -> Enumerate<Self> ⓘwhere
Self: Sized,
fn enumerate(self) -> Enumerate<Self> ⓘwhere
Self: Sized,
Creates an iterator which gives the current iteration count as well as
the next value. Read more
1.0.0 (const: unstable) · Sourcefn take_while<P>(self, predicate: P) -> TakeWhile<Self, P> ⓘ
fn take_while<P>(self, predicate: P) -> TakeWhile<Self, P> ⓘ
Creates an iterator that yields elements based on a predicate. Read more
1.57.0 (const: unstable) · Sourcefn map_while<B, P>(self, predicate: P) -> MapWhile<Self, P> ⓘ
fn map_while<B, P>(self, predicate: P) -> MapWhile<Self, P> ⓘ
Creates an iterator that both yields elements based on a predicate and maps. Read more
1.0.0 (const: unstable) · Sourcefn skip(self, n: usize) -> Skip<Self> ⓘwhere
Self: Sized,
fn skip(self, n: usize) -> Skip<Self> ⓘwhere
Self: Sized,
Creates an iterator that skips the first
n elements. Read more1.0.0 (const: unstable) · Sourcefn take(self, n: usize) -> Take<Self> ⓘwhere
Self: Sized,
fn take(self, n: usize) -> Take<Self> ⓘwhere
Self: Sized,
Creates an iterator that yields the first
n elements, or fewer
if the underlying iterator ends sooner. Read more1.0.0 (const: unstable) · Sourcefn scan<St, B, F>(self, initial_state: St, f: F) -> Scan<Self, St, F> ⓘ
fn scan<St, B, F>(self, initial_state: St, f: F) -> Scan<Self, St, F> ⓘ
1.0.0 (const: unstable) · Sourcefn flat_map<U, F>(self, f: F) -> FlatMap<Self, U, F> ⓘ
fn flat_map<U, F>(self, f: F) -> FlatMap<Self, U, F> ⓘ
Creates an iterator that works like map, but flattens nested structure. Read more
1.29.0 (const: unstable) · Sourcefn flatten(self) -> Flatten<Self> ⓘ
fn flatten(self) -> Flatten<Self> ⓘ
Creates an iterator that flattens nested structure. Read more
Sourcefn map_windows<F, R, const N: usize>(self, f: F) -> MapWindows<Self, F, N> ⓘ
fn map_windows<F, R, const N: usize>(self, f: F) -> MapWindows<Self, F, N> ⓘ
🔬This is a nightly-only experimental API. (
iter_map_windows)Calls the given function
f for each contiguous window of size N over
self and returns an iterator over the outputs of f. Like slice::windows(),
the windows during mapping overlap as well. Read more1.0.0 (const: unstable) · Sourcefn inspect<F>(self, f: F) -> Inspect<Self, F> ⓘ
fn inspect<F>(self, f: F) -> Inspect<Self, F> ⓘ
Does something with each element of an iterator, passing the value on. Read more
1.0.0 (const: unstable) · Sourcefn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,
fn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,
Creates a “by reference” adapter for this instance of
Iterator. Read more1.0.0 (const: unstable) · Sourcefn collect<B>(self) -> B
fn collect<B>(self) -> B
Transforms an iterator into a collection. Read more
Sourcefn try_collect<B>(
&mut self,
) -> <<Self::Item as Try>::Residual as Residual<B>>::TryType
fn try_collect<B>( &mut self, ) -> <<Self::Item as Try>::Residual as Residual<B>>::TryType
🔬This is a nightly-only experimental API. (
iterator_try_collect)Fallibly transforms an iterator into a collection, short circuiting if
a failure is encountered. Read more
Sourcefn collect_into<E>(self, collection: &mut E) -> &mut E
fn collect_into<E>(self, collection: &mut E) -> &mut E
🔬This is a nightly-only experimental API. (
iter_collect_into)Collects all the items from an iterator into a collection. Read more
1.0.0 (const: unstable) · Sourcefn partition<B, F>(self, f: F) -> (B, B)
fn partition<B, F>(self, f: F) -> (B, B)
Consumes an iterator, creating two collections from it. Read more
Sourcefn partition_in_place<'a, T, P>(self, predicate: P) -> usize
fn partition_in_place<'a, T, P>(self, predicate: P) -> usize
🔬This is a nightly-only experimental API. (
iter_partition_in_place)Reorders the elements of this iterator in-place according to the given predicate,
such that all those that return
true precede all those that return false.
Returns the number of true elements found. Read moreSourcefn is_partitioned<P>(self, predicate: P) -> bool
fn is_partitioned<P>(self, predicate: P) -> bool
🔬This is a nightly-only experimental API. (
iter_is_partitioned)Checks if the elements of this iterator are partitioned according to the given predicate,
such that all those that return
true precede all those that return false. Read more1.27.0 (const: unstable) · Sourcefn try_fold<B, F, R>(&mut self, init: B, f: F) -> R
fn try_fold<B, F, R>(&mut self, init: B, f: F) -> R
An iterator method that applies a function as long as it returns
successfully, producing a single, final value. Read more
1.27.0 (const: unstable) · Sourcefn try_for_each<F, R>(&mut self, f: F) -> R
fn try_for_each<F, R>(&mut self, f: F) -> R
An iterator method that applies a fallible function to each item in the
iterator, stopping at the first error and returning that error. Read more
1.0.0 (const: unstable) · Sourcefn fold<B, F>(self, init: B, f: F) -> B
fn fold<B, F>(self, init: B, f: F) -> B
Folds every element into an accumulator by applying an operation,
returning the final result. Read more
1.51.0 (const: unstable) · Sourcefn reduce<F>(self, f: F) -> Option<Self::Item>
fn reduce<F>(self, f: F) -> Option<Self::Item>
Reduces the elements to a single one, by repeatedly applying a reducing
operation. Read more
Sourcefn try_reduce<R>(
&mut self,
f: impl FnMut(Self::Item, Self::Item) -> R,
) -> <<R as Try>::Residual as Residual<Option<<R as Try>::Output>>>::TryType
fn try_reduce<R>( &mut self, f: impl FnMut(Self::Item, Self::Item) -> R, ) -> <<R as Try>::Residual as Residual<Option<<R as Try>::Output>>>::TryType
🔬This is a nightly-only experimental API. (
iterator_try_reduce)Reduces the elements to a single one by repeatedly applying a reducing operation. If the
closure returns a failure, the failure is propagated back to the caller immediately. Read more
1.0.0 (const: unstable) · Sourcefn all<F>(&mut self, f: F) -> bool
fn all<F>(&mut self, f: F) -> bool
Tests if every element of the iterator matches a predicate. Read more
1.0.0 (const: unstable) · Sourcefn any<F>(&mut self, f: F) -> bool
fn any<F>(&mut self, f: F) -> bool
Tests if any element of the iterator matches a predicate. Read more
1.0.0 (const: unstable) · Sourcefn find<P>(&mut self, predicate: P) -> Option<Self::Item>
fn find<P>(&mut self, predicate: P) -> Option<Self::Item>
Searches for an element of an iterator that satisfies a predicate. Read more
1.30.0 (const: unstable) · Sourcefn find_map<B, F>(&mut self, f: F) -> Option<B>
fn find_map<B, F>(&mut self, f: F) -> Option<B>
Applies function to the elements of iterator and returns
the first non-none result. Read more
Sourcefn try_find<R>(
&mut self,
f: impl FnMut(&Self::Item) -> R,
) -> <<R as Try>::Residual as Residual<Option<Self::Item>>>::TryType
fn try_find<R>( &mut self, f: impl FnMut(&Self::Item) -> R, ) -> <<R as Try>::Residual as Residual<Option<Self::Item>>>::TryType
🔬This is a nightly-only experimental API. (
try_find)Applies function to the elements of iterator and returns
the first true result or the first error. Read more
1.0.0 (const: unstable) · Sourcefn position<P>(&mut self, predicate: P) -> Option<usize>
fn position<P>(&mut self, predicate: P) -> Option<usize>
Searches for an element in an iterator, returning its index. Read more
1.0.0 (const: unstable) · Sourcefn rposition<P>(&mut self, predicate: P) -> Option<usize>
fn rposition<P>(&mut self, predicate: P) -> Option<usize>
Searches for an element in an iterator from the right, returning its
index. Read more
1.6.0 (const: unstable) · Sourcefn max_by_key<B, F>(self, f: F) -> Option<Self::Item>
fn max_by_key<B, F>(self, f: F) -> Option<Self::Item>
Returns the element that gives the maximum value from the
specified function. Read more
1.15.0 (const: unstable) · Sourcefn max_by<F>(self, compare: F) -> Option<Self::Item>
fn max_by<F>(self, compare: F) -> Option<Self::Item>
Returns the element that gives the maximum value with respect to the
specified comparison function. Read more
1.6.0 (const: unstable) · Sourcefn min_by_key<B, F>(self, f: F) -> Option<Self::Item>
fn min_by_key<B, F>(self, f: F) -> Option<Self::Item>
Returns the element that gives the minimum value from the
specified function. Read more
1.15.0 (const: unstable) · Sourcefn min_by<F>(self, compare: F) -> Option<Self::Item>
fn min_by<F>(self, compare: F) -> Option<Self::Item>
Returns the element that gives the minimum value with respect to the
specified comparison function. Read more
1.0.0 (const: unstable) · Sourcefn rev(self) -> Rev<Self> ⓘwhere
Self: Sized + DoubleEndedIterator,
fn rev(self) -> Rev<Self> ⓘwhere
Self: Sized + DoubleEndedIterator,
Reverses an iterator’s direction. Read more
1.0.0 (const: unstable) · Sourcefn unzip<A, B, FromA, FromB>(self) -> (FromA, FromB)
fn unzip<A, B, FromA, FromB>(self) -> (FromA, FromB)
Converts an iterator of pairs into a pair of containers. Read more
1.36.0 (const: unstable) · Sourcefn copied<'a, T>(self) -> Copied<Self> ⓘ
fn copied<'a, T>(self) -> Copied<Self> ⓘ
Creates an iterator which copies all of its elements. Read more
Sourcefn array_chunks<const N: usize>(self) -> ArrayChunks<Self, N> ⓘwhere
Self: Sized,
fn array_chunks<const N: usize>(self) -> ArrayChunks<Self, N> ⓘwhere
Self: Sized,
🔬This is a nightly-only experimental API. (
iter_array_chunks)Returns an iterator over
N elements of the iterator at a time. Read more1.11.0 (const: unstable) · Sourcefn product<P>(self) -> P
fn product<P>(self) -> P
Iterates over the entire iterator, multiplying all the elements. Read more
Sourcefn cmp_by<I, F>(self, other: I, cmp: F) -> Ordering
fn cmp_by<I, F>(self, other: I, cmp: F) -> Ordering
🔬This is a nightly-only experimental API. (
iter_order_by)Lexicographically compares the elements of this
Iterator with those
of another with respect to the specified comparison function. Read more1.5.0 (const: unstable) · Sourcefn partial_cmp<I>(self, other: I) -> Option<Ordering>
fn partial_cmp<I>(self, other: I) -> Option<Ordering>
Lexicographically compares the
PartialOrd elements of
this Iterator with those of another. The comparison works like short-circuit
evaluation, returning a result without comparing the remaining elements.
As soon as an order can be determined, the evaluation stops and a result is returned. Read moreSourcefn partial_cmp_by<I, F>(self, other: I, partial_cmp: F) -> Option<Ordering>where
Self: Sized,
I: IntoIterator,
F: FnMut(Self::Item, <I as IntoIterator>::Item) -> Option<Ordering>,
fn partial_cmp_by<I, F>(self, other: I, partial_cmp: F) -> Option<Ordering>where
Self: Sized,
I: IntoIterator,
F: FnMut(Self::Item, <I as IntoIterator>::Item) -> Option<Ordering>,
🔬This is a nightly-only experimental API. (
iter_order_by)Lexicographically compares the elements of this
Iterator with those
of another with respect to the specified comparison function. Read moreSourcefn eq_by<I, F>(self, other: I, eq: F) -> bool
fn eq_by<I, F>(self, other: I, eq: F) -> bool
🔬This is a nightly-only experimental API. (
iter_order_by)1.5.0 (const: unstable) · Sourcefn lt<I>(self, other: I) -> bool
fn lt<I>(self, other: I) -> bool
Determines if the elements of this
Iterator are lexicographically
less than those of another. Read more1.5.0 (const: unstable) · Sourcefn le<I>(self, other: I) -> bool
fn le<I>(self, other: I) -> bool
Determines if the elements of this
Iterator are lexicographically
less or equal to those of another. Read more1.5.0 (const: unstable) · Sourcefn gt<I>(self, other: I) -> bool
fn gt<I>(self, other: I) -> bool
Determines if the elements of this
Iterator are lexicographically
greater than those of another. Read more1.5.0 (const: unstable) · Sourcefn ge<I>(self, other: I) -> bool
fn ge<I>(self, other: I) -> bool
Determines if the elements of this
Iterator are lexicographically
greater than or equal to those of another. Read more1.82.0 (const: unstable) · Sourcefn is_sorted(self) -> bool
fn is_sorted(self) -> bool
Checks if the elements of this iterator are sorted. Read more
1.82.0 (const: unstable) · Sourcefn is_sorted_by<F>(self, compare: F) -> bool
fn is_sorted_by<F>(self, compare: F) -> bool
Checks if the elements of this iterator are sorted using the given comparator function. Read more